@@ -2,5 +2,3 @@
 ( cd etc/rc.d ; ln -sf /usr/lib/news/bin/rc.news rc.news )
 ( cd usr/bin ; rm -rf inews )
 ( cd usr/bin ; ln -sf /usr/lib/news/bin/inews inews )
-( cd usr/lib/news/bin ; rm -rf ovdb_upgrade )
-( cd usr/lib/news/bin ; ln -sf ovdb_recover ovdb_upgrade )
